package com.tomwheeler.addrbook;

import com.tomwheeler.addrbook.ContactDetailForm;
import com.tomwheeler.addrbook.ContactDataUtil;

// standard java classes
import java.sql.SQLException;
import java.util.Locale;

// java extension classes
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

// third-party classes
import org.apache.commons.beanutils.PropertyUtils;
import org.apache.struts.action.Action;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionError;
import org.apache.struts.action.ActionMessages;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.util.MessageResources;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
*  This is a Struts Action Class that deletes the record 
*  for a single contact in the database AddressBook application.
*
*@author     T. Wheeler (tom@stlwebdev.org)
*/
public class DeleteContactUpdateAction extends Action 
{
    // set up the logger on instantiation
    private static Log logger = LogFactory.getLog(DeleteContactUpdateAction.class);
    
    /**
    * This is the &quot;Main&quot; method for ActionClasses
    *
    * @param  mapping   An ActionMapping instance
    * @param  form      The ActionForm that was set up in struts-config.xml
    * @param  request   An HTTPServletRequest object
    * @param  response  An HTTPServletResponse object
    * @return           An ActionForward instance
    */
    public ActionForward execute(
            ActionMapping mapping,
            ActionForm form,
            HttpServletRequest request,
            HttpServletResponse response) 
    {
        logger.debug(" we have a generic form object; cast it to a ContactDetailForm");
        ContactDetailForm contactForm = (ContactDetailForm) form;

        try 
        {
            ContactDataUtil dataUtil = new ContactDataUtil();
            dataUtil.deleteContact(contactForm);
             
            ActionMessages messages = new ActionMessages();
            messages.add(ActionMessages.GLOBAL_MESSAGE, 
                new ActionMessage("status.contact.delete.success"));
            saveMessages(request, messages);    
            logger.info("Deletion of contact record was succssful");
                
            // remove the obsolete form bean we don't need it any more.   
            // We don't want to assume that it is in a particular scope, as that 
            // is configured via the struts-config.xml (so we check it first).
            if (mapping.getAttribute() != null) 
            {
                if ("request".equals(mapping.getScope())) 
                {
                    request.removeAttribute(mapping.getAttribute());
                } 
                else 
                {
                    javax.servlet.http.HttpSession session = request.getSession();            
                    session.removeAttribute(mapping.getAttribute());
                }
            }                
        }
        catch (SQLException sqle) 
        {
            // show a brief error message to the client
            ActionErrors errors = new ActionErrors();
            errors.add(ActionErrors.GLOBAL_ERROR, 
                new ActionError("error.database.generic"));
            saveErrors(request, errors);
            
            // store the more complete message in the logs
            logger.error("Failed due to database error " + sqle.toString());                  
        } 
        
        return mapping.findForward("mainPage");
    }
}

