package com.tomwheeler.addrbook;

import com.tomwheeler.addrbook.ContactsListForm;

// standard java classes
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Locale;
import java.util.Vector;

// java extension classes
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.sql.DataSource;

// third-party classes
import org.apache.commons.beanutils.PropertyUtils;
import org.apache.struts.action.Action;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.util.MessageResources;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
*  This is a Struts Action Class that handles accessing the 
*  detail information for all contacts in the AddressBook 
*  application.  This is shown on the List Contacts page.
*
*@author     T. Wheeler (tom@stlwebdev.org)
*/
public class ListContactsAction extends Action 
{
    // set up the logger on instantiation
    private static Log logger = LogFactory.getLog(ListContactsAction.class);
    
    /**
    * This is the &quot;Main&quot; method for ActionClasses
    *
    * @param  mapping   An ActionMapping instance
    * @param  form      The ActionForm that was set up in struts-config.xml
    * @param  request   An HTTPServletRequest object
    * @param  response  An HTTPServletResponse object
    * @return           An ActionForward instance
    */
    public ActionForward execute(
            ActionMapping mapping,
            ActionForm form,
            HttpServletRequest request,
            HttpServletResponse response) 
    {        
        // scope the datebase objects
        DataSource dataSource = null;
        Connection conn = null;
        PreparedStatement stmt = null;
        ResultSet rs = null;
        
        Vector contacts = new Vector();
        
        logger.debug(" we have a generic form object; cast it to a ContactListForm");
        ContactsListForm contactsList = (ContactsListForm) form;

        // TODO : Factor this out and put it in ContactDataUtil class
        try 
        {
            ContactDataUtil dataUtil = new ContactDataUtil();
            conn = dataUtil.getConnection();
            
            StringBuffer sqlBuff = new StringBuffer();
            sqlBuff.append("select * from Contacts order by lastName");
            
            stmt = conn.prepareStatement(sqlBuff.toString());
            
            rs = stmt.executeQuery();

            while (rs.next()) 
            {
                ContactDetailForm contactForm = new ContactDetailForm();
                contactForm.setContactId(rs.getString("contactId"));
                contactForm.setFirstName(rs.getString("firstName"));
                contactForm.setLastName(rs.getString("lastName"));
                contactForm.setAddrLine1(rs.getString("addrLine1"));
                contactForm.setAddrLine2(rs.getString("addrLine2"));
                contactForm.setCity(rs.getString("city"));
                contactForm.setState(rs.getString("state"));
                contactForm.setZipCode(rs.getString("zipCode"));
                contactForm.setHomePhone(rs.getString("homePhone"));
                contactForm.setWorkPhone(rs.getString("workPhone"));
                contactForm.setCellPhone(rs.getString("cellPhone"));
                contactForm.setEmailAddr(rs.getString("emailAddr"));
                contactForm.setComments(rs.getString("comments"));
                contacts.add(contactForm);
                logger.debug("populated contact detail form for contactId " + 
                    contactForm.getContactId());
            }
            logger.info("successfully populated contact list form");
        }
        catch (SQLException sqle) 
        {
            logger.error("Failed due to database error " + sqle.toString());
        } 
        finally 
        {
            //enclose this in a finally block to ensure connection closing
            try 
            {
                rs.close();
                stmt.close();
                conn.close();
            } 
            catch (SQLException e) 
            {
                logger.error("Failed due to database error " + e.toString());
            }
        }

        contactsList.setContactList(contacts);
        return mapping.findForward("displayContactsList");
    }
}
